// Copyright Epic Games, Inc. All Rights Reserved.

using UnrealBuildTool;
using System.IO;

namespace UnrealBuildTool.Rules
{
	public class AppGuardSDK : ModuleRules
	{
		public AppGuardSDK(ReadOnlyTargetRules Target) : base(Target)
		{
			PCHUsage = ModuleRules.PCHUsageMode.UseExplicitOrSharedPCHs;

			PrivatePCHHeaderFile = "Private/AppGuardSDKPrivatePCH.h";
			PublicIncludePaths.AddRange(
				new string[] {
					"AppGuardSDK/Public"
					// ... add public include paths required here ...
				}
				);
					
			
			PrivateIncludePaths.AddRange(
				new string[] {
					"AppGuardSDK/Private"
					// ... add other private include paths required here ...
				}
				);
				
			
			PublicDependencyModuleNames.AddRange(
				new string[]
				{
					"Engine",
					"Core",
					"CoreUObject",
					"Slate",
					"SlateCore",
					"UMG"
					// ... add other public dependencies that you statically link with here ...
				}
				);
				
			
			PrivateDependencyModuleNames.AddRange(
				new string[]
				{
					// ... add private dependencies that you statically link with here ...	
				}
				);
			
			
			DynamicallyLoadedModuleNames.AddRange(
				new string[]
				{
					// ... add any modules that your module loads dynamically here ...
				}
				);

			if(Target.Platform == UnrealTargetPlatform.Android)
			{
				string PluginPath = Utils.MakePathRelativeTo(ModuleDirectory, Target.RelativeEnginePath);
				AdditionalPropertiesForReceipt.Add(new ReceiptProperty("AndroidPlugin", Path.Combine(PluginPath, "AppGuardSDK_APL.xml")));
			}
            
            if(Target.Platform == UnrealTargetPlatform.IOS)
            {
                PrivateIncludePaths.Add("AppGuardSDK/Private/IOS");
                PublicFrameworks.AddRange(
                    new string[]
                    {
                        "AppGuardCore",
                        "Security"
                    }
                );
                
                string PluginPath = Utils.MakePathRelativeTo(ModuleDirectory, Target.RelativeEnginePath);
                AdditionalPropertiesForReceipt.Add("IOSPlugin", Path.Combine(PluginPath, "AppGuardSDK_UPL_IOS.xml"));
            }
		}
	}
	}
