#include "AppGuardUE4Manager.h"

#if PLATFORM_ANDROID
#include "Android/AndroidApplication.h"
#include "Android/AppGuardSDKJNI.h"
#include "Android/AndroidJava.h"
#include <android/log.h>
#include "Engine.h"
#endif // #if PLATFORM_ANDROID

#if PLATFORM_IOS
#include "AppGuardSDKiOS.h"
#include "Engine.h"
#endif // #if PLATFORM_IOS

AppGuardUE4Manager* AppGuardUE4Manager::instance_ = nullptr;

AppGuardUE4Manager& AppGuardUE4Manager::GetInstance() {
    if (instance_ == nullptr) {
        instance_ = new AppGuardUE4Manager();
    }

    return *instance_;
}

AppGuardUE4Manager::AppGuardUE4Manager() {
#if PLATFORM_ANDROID
    __android_log_print(ANDROID_LOG_VERBOSE,"TEST", "AppGuardUE4Manager");
#endif
    init();

}

/*
*  AppGuard 에서 서버인증 수행한 결과를 수신하는 메서드입니다.
*  Param : const char *data
*   - 결과 값. (ex: 1,)
*/



/*
*  보안 진단 이벤트를 수신하는 메서드입니다.
*  Param : int value
*   - 진단 코드를 나타냅니다.
*   - 양수일 경우 kill, 음수일 경우 report 입니다.
*/


void AppGuardUE4Manager::init() {
#if PLATFORM_ANDROID
    JNIEnv* Env = FAndroidApplication::GetJavaEnv();
    jclass jBridgeClass = FAndroidApplication::FindJavaClass("com/inca/security/AppGuard/AppGuardClientUnrealBridge");

    FAndroidApplication::CheckJavaException();
    if (jBridgeClass != nullptr) {
        jmethodID constructorID = Env->GetMethodID(jBridgeClass, "<init>", "()V");
        if(constructorID != nullptr) {
            mAppGuardClientUnrealBridge = Env->NewObject(jBridgeClass, constructorID);    
        }
    }
#endif // #if PLATFORM_ANDROID
}

void AppGuardUE4Manager::Start() {
#if PLATFORM_IOS
    AppGuardInit();
#endif

}
void AppGuardUE4Manager::SetUserId(FString userId) {
#if PLATFORM_ANDROID    
    JNIEnv* Env = FAndroidApplication::GetJavaEnv();
    jclass jBridgeClass = FAndroidApplication::FindJavaClass("com/inca/security/AppGuard/AppGuardClientUnrealBridge");

    FAndroidApplication::CheckJavaException();
    if (jBridgeClass != nullptr) {
        jmethodID constructorID = Env->GetMethodID(jBridgeClass, "setUserId", "(Ljava/lang/String;)V");
        if(constructorID != nullptr) {
            jstring jUserId = Env->NewStringUTF(TCHAR_TO_UTF8(*userId));
            Env->CallVoidMethod(mAppGuardClientUnrealBridge, constructorID, jUserId);
        }
    }
#endif // #if PLATFORM_ANDROID
    
#if PLATFORM_IOS
    AppGuardSetUserID(TCHAR_TO_UTF8(*userId));
#endif
}

void AppGuardUE4Manager::SetUniqueClientId(FString uniqueId, long retryTimeSec) {
#if PLATFORM_ANDROID
    JNIEnv* Env = FAndroidApplication::GetJavaEnv();
    jclass jBridgeClass = FAndroidApplication::FindJavaClass("com/inca/security/AppGuard/AppGuardClientUnrealBridge");

    FAndroidApplication::CheckJavaException();
    if (jBridgeClass != nullptr) {
        jmethodID constructorID = Env->GetMethodID(jBridgeClass, "setUniqueClientID", "(Ljava/lang/String;I)V");
        if(constructorID != nullptr) {
            jstring jUniqueId = uniqueId.IsEmpty() ? nullptr : Env->NewStringUTF(TCHAR_TO_UTF8(*uniqueId));
            Env->CallVoidMethod(mAppGuardClientUnrealBridge, constructorID, jUniqueId, 30);
        }
    }
#endif // #if PLATFORM_ANDROID
    
#if PLATFORM_IOS
    AppGuardSetCertificationID(TCHAR_TO_UTF8(*uniqueId), 180);
#endif
}
